pub type ScrollbarInset = GenericScrollbarInset<NonNegativeLength>;Expand description
A computed value for the -moz-scrollbar-inset-block / -inline properties.
Aliased Type
#[repr(C)]pub struct ScrollbarInset {
pub start: NonNegative<CSSPixelLength>,
pub end: NonNegative<CSSPixelLength>,
}Fields
start: NonNegative<CSSPixelLength>The inset at the logical start of the axis.
end: NonNegative<CSSPixelLength>The inset at the logical end of the axis.